from emod_api import schema_to_class as s2c
import emod_api.interventions.common as common
import emod_api.interventions.utils as utils
from emodpy_tbhiv.interventions import purge_campaign_event

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch

def HIVDiagnostic(
        camp,
        trigger_treatment_list,
        base_sensitivity=1.0,
        base_specificity=1.0,
        pos_event='HIVTestedPositive',
        neg_event='HIVTestedNegative',
        treatment_fraction= 1,
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='HIV Diagnostic'):
    """
    HIVDiagnostic
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    intervention = s2c.get_class_with_defaults( "HIVSimpleDiagnostic", schema_path )
    intervention.Base_Sensitivity = base_sensitivity
    intervention.Base_Specificity = base_specificity
    intervention.Treatment_Fraction = treatment_fraction
    intervention.Positive_Diagnosis_Event = camp.get_send_trigger( pos_event )
    intervention.Negative_Diagnosis_Event = camp.get_send_trigger( neg_event )

    event = common.TriggeredCampaignEvent( camp, start_day,event_name, utils.do_nodes( camp.schema_path, nodeIDs ), trigger_treatment_list, [ intervention ], Duration=duration, Property_Restrictions=property_restrictions_list )
    purge_campaign_event( event )

    return event

def new_intervention_as_file( camp, filename=None ):
    camp.add( HIVDiagnostic( camp, trigger_treatment_list=[ "Births" ] ) )
    if filename is None:
        filename = "hiv_diag.json"

    camp.save( filename )
    return filename

